==> ltb-project-service-desk-0.6.2.tar.gz: ltb-project-service-desk-0.6.2/lang/en.inc.php <==
<?php

#==============================================================================
# English
#==============================================================================

$messages['accountenabled'] = "Account is enabled";
$messages['accountdisabled'] = "Account is disabled";
$messages['auditlogs'] = "Audit logs";
$messages['auditlogtitle'] = "Audit log for the last $audit_log_days days";
$messages['accountlocked'] = "Account is locked";
$messages['accountnotdisabled'] = "Fail to disable account";
$messages['accountnotenabled'] = "Fail to enable account";
$messages['accountnotlocked'] = "Fail to lock account";
$messages['accountnotunlocked'] = "Fail to unlock account";
$messages['accountnotvalid'] = "Account is not valid";
$messages['accountunlocked'] = "Account is not locked";
$messages['accountstatus'] = "Account status";
$messages['accountvalid'] = "Account is valid";
$messages['actionforbidden'] = "Action forbidden";
$messages['changesubject'] = "Your password has been changed";
$messages['changesubjectforadmin'] = "User password has been changed";
$messages['changemessage'] = "Hello {name},\n\nYour password has been changed.\n\nIf you didn't request a password reset, please contact your administrator for details.";
$messages['changemessageforadmin'] = "Hello,\n\nThe password of account {dn} has been changed.\n.";
$messages['checkpassword'] = "Check password";
$messages['close'] = "Close";
$messages['comment_needed'] = "A comment will be asked";
$messages['currentpassword'] = "Current password";
$messages['dashboards'] = "Dashboards";
$messages['disableaccount'] = "Disable account";
$messages['disabledaccounts'] = "Disabled accounts";
$messages['displayentry'] = "Display entry";
$messages['dnrequired'] = "Entry identifier required";
$messages['editentry'] = "Edit entry";
$messages['enableaccount'] = "Enable account";
$messages['enddate'] = "End date";
$messages['entriesfound'] = "entries found";
$messages['entryfound'] = "entry found";
$messages['eventfound'] = "event found";
$messages['eventsfound'] = "events found";
$messages['expiredaccounts'] = "Passwords expired";
$messages['false'] = "No";
$messages['forcereset'] = "Force reset at next connection";
$messages['hookerror'] = "An error occured in the hook";
$messages['idleaccounts'] = "Idle accounts";
$messages['idleaccountstitle'] = "Accounts idle for more than $idledays days";
$messages['insert_comment'] = "Insert comment";
$messages['invalidaccounts'] = "Invalid accounts";
$messages['invalidaccountstitle'] = "Invalid accounts";
$messages['pager_all'] = "All";
$messages['print_all'] = "Print all results";
$messages['print_page'] = "Print this page";
$messages['label_action'] = "Action";
$messages['label_authtimestamp'] = "Last authentication";
$messages['label_businesscategory'] = "Business category";
$messages['label_carlicense'] = "Car license";
$messages['label_comment'] = "Comment";
$messages["label_created"] = "Created";
$messages['label_date'] = "Date";
$messages['label_description'] = "Description";
$messages['label_displayname'] = "Display name";
$messages['label_done_by'] = "Done by";
$messages['label_employeenumber'] = "Employee number";
$messages['label_employeetype'] = "Employee type";
$messages['label_endtime'] = "End of validity";
$messages['label_expirationdate'] = "Expiration date";
$messages['label_fax'] = "Fax";
$messages['label_firstname'] = "First name";
$messages['label_fullname'] = "Full name";
$messages['label_identifier'] = "Identifier";
$messages['label_ip'] = "IP Address";
$messages['label_l'] = "Locality";
$messages['label_lastname'] = "Last name";
$messages['label_mail'] = "Mail";
$messages['label_mailquota'] = "Mail quota";
$messages['label_manager'] = "Manager";
$messages['label_mobile'] = "Mobile";
$messages["label_modified"] = "Modified";
$messages['label_organization'] = "Organization";
$messages['label_organizationalunit'] = "Organizational Unit";
$messages['label_pager'] = "Pager";
$messages['label_phone'] = "Phone";
$messages['label_postaladdress'] = "Address";
$messages['label_postalcode'] = "Postal code";
$messages['label_pwdaccountlockedtime'] = "Locking date";
$messages['label_pwdchangedtime'] = "Last password change";
$messages['label_pwdfailuretime'] = "Last authentication failures";
$messages['label_pwdgraceusetime'] = "Last grace authentications";
$messages['label_pwdlastsuccess'] = $messages['label_authtimestamp'];
$messages['label_pwdpolicysubentry'] = "Associated password policy";
$messages['label_pwdreset'] = "Reset password at next connection";
$messages['label_result'] = "Result";
$messages['label_secretary'] = "Secretary";
$messages['label_starttime'] = "Start of validity";
$messages['label_state'] = "State";
$messages['label_street'] = "Street";
$messages['label_title'] = "Title";
$messages['label_user_dn'] = "User";
$messages['ldaperror'] = "LDAP communication error";
$messages['lockaccount'] = "Lock account";
$messages['lockedaccounts'] = "Locked accounts";
$messages['logout'] = "Logout";
$messages['newpassword'] = "New password";
$messages['noentriesfound'] = "No entries found";
$messages['noeventsfound'] = "No events found";
$messages['notdefined'] = "Not defined";
$messages['password'] = "Password";
$messages['passwordchanged'] = "Password changed";
$messages['passwordexpired'] = "Password is expired";
$messages['passwordinvalid'] = "Authentication has failed";
$messages['passwordok'] = "Authentication succeeds!";
$messages['passwordrefused'] = "Password was refused";
$messages['passwordinhistory'] = "Password in history";
$messages['passwordrequired'] = "Please enter the password";
$messages['resetpassword'] = "Reset password";
$messages['search'] = "Search";
$messages['searchrequired'] = "Please enter your search";
$messages['sizelimit'] = "Size limit has been reached, some entries could not be displayed";
$messages['startdate'] = "Start date";
$messages['submit'] = "Submit";
$messages['title'] = "Service Desk";
$messages['title_search'] = "Search results:";
$messages['tooltip_emailto'] = "Send an email";
$messages['tooltip_phoneto'] = "Dial this number";
$messages['true'] = "Yes";
$messages['unlockaccount'] = "Unlock account";
$messages['unlockdate'] = "Automatic unlock date:";
$messages['welcome'] = "Welcome to LDAP Tool Box service desk";
$messages['willexpireaccounts'] = "Passwords soon expired";
$messages['willexpireaccountstitle'] = "Passwords that will expire within $willexpiredays days";
$messages['notcomplex'] = "Your password does not have enough different classes of characters";
$messages['tooshort'] = "Your password is too short";
$messages['toobig'] = "Your password is too long";
$messages['minlower'] = "Your password does not have enough lowercase characters";
$messages['policyminlower'] = "Minimum number of lowercase characters:";
$messages['minupper'] = "Your password does not have enough uppercase characters";
$messages['policyminupper'] = "Minimum number of uppercase characters:";
$messages['mindigit'] = "Your password does not have enough digits";
$messages['policymindigit'] = "Minimum number of digits:";
$messages['minspecial'] = "Your password does not have enough special characters";
$messages['policyminspecial'] = "Minimum number of special characters:";
$messages['forbiddenchars'] = "You password contains forbidden characters";
$messages['policyforbiddenchars'] = "Forbidden characters:";
$messages['specialatends'] = "Your new password has its only special character at the beginning or end";
$messages['policyspecialatends'] = "Your new password may not have its only special character at the beginning or end";
$messages['sameasold'] = "Your new password is identical to your old password";
$messages['sameaslogin'] = "Your new password is identical to your login";
$messages['policydiffminchars'] = "Minimum number of new unique characters:";
$messages['diffminchars'] = "Your new password is too similar to your old password";
$messages['forbiddenwords'] = "Your passwords contains forbidden words or strings";
$messages['policyforbiddenwords'] = "Your password must not contain:";
$messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
$messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
$messages['sameascustompwd'] = "The new password is not unique across other password fields";
$messages['pwned'] = "Your new password has already been published on leaks, you should consider changing it on any other service that it is in use";
$messages['policypwned'] = "Your new password may not be published on any previous public password leak from any site";
$messages['insufficiententropy'] = "Insufficient entropy for new password";
$messages['policy'] = "Your password must conform to the following constraints:";
$messages['policyminlength'] = "Minimum length:";
$messages['policymaxlength'] = "Maximum length:";
$messages['policyminlower'] = "Minimum number of lowercase characters:";
$messages['policyminupper'] = "Minimum number of uppercase characters:";
$messages['policymindigit'] = "Minimum number of digits:";
$messages['policyminspecial'] = "Minimum number of special characters:";
$messages['policycomplex'] = "Minimum number of different classes of characters:";
$messages['policyforbiddenchars'] = "Forbidden characters:";
$messages['policydiffminchars'] = "Minimum number of new unique characters:";
$messages['policynoreuse'] = "Your new password may not be the same as your old password";
$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
$messages['policydifflogin'] = "Your new password may not be the same as your login";
$messages['policypwned'] = "Your new password may not be published on any previous public password leak from any site";
$messages['policyspecialatends'] = "Your new password may not have its only special character at the beginning or end";
$messages['policyentropy'] = "Password strength";
$messages['updatevaliditydates'] = "Update validity dates";
$messages['validitydatesnotupdated'] = "Error when updating validity dates";
$messages['validitydatesupdated'] = "Validity dates updated";

?>

==> ltb-project-service-desk-0.8.tar.gz: ltb-project-service-desk-0.8/lang/en.inc.php <==
<?php

#==============================================================================
# English
#==============================================================================

$messages['accountdisabled'] = "Account is disabled";
$messages['accountenabled'] = "Account is enabled";
$messages['accountlocked'] = "Account is locked";
$messages['accountnotdisabled'] = "Fail to disable account";
$messages['accountnotenabled'] = "Fail to enable account";
$messages['accountnotlocked'] = "Fail to lock account";
$messages['accountnotunlocked'] = "Fail to unlock account";
$messages['accountnotvalid'] = "Account is not valid";
$messages['accountstatus'] = "Account status";
$messages['accountunlocked'] = "Account is not locked";
$messages['accountvalid'] = "Account is valid";
$messages['actionforbidden'] = "Action forbidden";
$messages['allaccounts'] = "List of all acoounts";
$messages['auditlogs'] = "Audit logs";
$messages['auditlogtitle'] = "Audit log for the last $audit_log_days days";
$messages['cancelbacktoentry'] = "Cancel and go back to entry";
$messages['changemessageforadmin'] = "Hello,\n\nThe password of account {dn} has been changed.\n.";
$messages['changemessage'] = "Hello {name},\n\nYour password has been changed.\n\nIf you didn't request a password reset, please contact your administrator for details.";
$messages['changesubjectforadmin'] = "User password has been changed";
$messages['changesubject'] = "Your password has been changed";
$messages['checkpassword'] = "Check password";
$messages['close'] = "Close";
$messages['comment_needed'] = "A comment will be asked";
$messages['createentry'] = "Create entry";
$messages['createfailed'] = "Creation has failed";
$messages['createok'] = "Entry has been created";
$messages['currentpassword'] = "Current password";
$messages['dashboards'] = "Dashboards";
$messages['deleteconfirmation'] = "Are you sure that you want to delete this entry?";
$messages['deleteentry'] = "Delete";
$messages['deletefailed'] = "Deletion has failed";
$messages['deleteok'] = "Entry has been deleted";
$messages['diffminchars'] = "Your new password is too similar to your old password";
$messages['disableaccount'] = "Disable account";
$messages['disabledaccounts'] = "Disabled accounts";
$messages['displayentry'] = "Display entry";
$messages['dnrequired'] = "Entry identifier required";
$messages['editentry'] = "Edit";
$messages['enableaccount'] = "Enable account";
$messages['enddate'] = "End date";
$messages['entriesfound'] = "entries found";
$messages['entryfound'] = "entry found";
$messages['eventfound'] = "event found";
$messages['eventsfound'] = "events found";
$messages['expiredaccounts'] = "Passwords expired";
$messages['false'] = "No";
$messages['forbiddenchars'] = "You password contains forbidden characters";
$messages['forbiddenldapfields'] = "Your password contains values from your LDAP entry";
$messages['forbiddenwords'] = "Your passwords contains forbidden words or strings";
$messages['forcereset'] = "Force reset at next connection";
$messages['hookerror'] = "An error occured in the hook";
$messages['idleaccounts'] = "Idle accounts";
$messages['idleaccountstitle'] = "Accounts idle for more than $idledays days";
$messages['insert_comment'] = "Insert comment";
$messages['insufficiententropy'] = "Insufficient entropy for new password";
$messages['invalidaccounts'] = "Invalid accounts";
$messages['invalidaccountstitle'] = "Invalid accounts";
$messages['label_action'] = "Action";
$messages['label_authtimestamp'] = "Last authentication";
$messages['label_businesscategory'] = "Business category";
$messages['label_carlicense'] = "Car license";
$messages['label_comment'] = "Comment";
$messages["label_created"] = "Created";
$messages['label_date'] = "Date";
$messages['label_description'] = "Description";
$messages['label_displayname'] = "Display name";
$messages['label_done_by'] = "Done by";
$messages['label_employeenumber'] = "Employee number";
$messages['label_employeetype'] = "Employee type";
$messages['label_endtime'] = "End of validity";
$messages['label_expirationdate'] = "Expiration date";
$messages['label_fax'] = "Fax";
$messages['label_firstname'] = "First name";
$messages['label_fullname'] = "Full name";
$messages['label_identifier'] = "Identifier";
$messages['label_ip'] = "IP Address";
$messages['label_lastname'] = "Last name";
$messages['label_l'] = "Locality";
$messages['label_mail'] = "Mail";
$messages['label_mailquota'] = "Mail quota";
$messages['label_manager'] = "Manager";
$messages['label_mobile'] = "Mobile";
$messages["label_modified"] = "Modified";
$messages['label_organizationalunit'] = "Organizational Unit";
$messages['label_organization'] = "Organization";
$messages['label_pager'] = "Pager";
$messages['label_phone'] = "Phone";
$messages['label_postaladdress'] = "Address";
$messages['label_postalcode'] = "Postal code";
$messages['label_pwdaccountlockedtime'] = "Locking date";
$messages['label_pwdchangedtime'] = "Last password change";
$messages['label_pwdfailuretime'] = "Last authentication failures";
$messages['label_pwdgraceusetime'] = "Last grace authentications";
$messages['label_pwdhistory'] = "Password change history";
$messages['label_pwdlastsuccess'] = $messages['label_authtimestamp'];
$messages['label_pwdpolicysubentry'] = "Associated password policy";
$messages['label_pwdreset'] = "Reset password at next connection";
$messages['label_result'] = "Result";
$messages['label_sambaPwdLastSet'] = "Last password change";
$messages['label_sambaPwdCanChange'] = "Date of allowed password change";
$messages['label_sambaPwdMustChange'] = "Date of mandatory password change";
$messages['label_sambaKickoffTime'] = "Automatic logout date";
$messages['label_secretary'] = "Secretary";
$messages['label_starttime'] = "Start of validity";
$messages['label_state'] = "State";
$messages['label_street'] = "Street";
$messages['label_title'] = "Title";
$messages['label_user_dn'] = "User";
$messages['ldaperror'] = "LDAP communication error";
$messages['lockaccount'] = "Lock account";
$messages['lockedaccounts'] = "Locked accounts";
$messages['logout'] = "Logout";
$messages['mindigit'] = "Your password does not have enough digits";
$messages['minlower'] = "Your password does not have enough lowercase characters";
$messages['minspecial'] = "Your password does not have enough special characters";
$messages['minupper'] = "Your password does not have enough uppercase characters";
$messages['newpassword'] = "New password";
$messages['newvalue'] = "New value";
$messages['noentriesfound'] = "No entries found";
$messages['noeventsfound'] = "No events found";
$messages['notcomplex'] = "Your password does not have enough different classes of characters";
$messages['notdefined'] = "Not defined";
$messages['oldvalue'] = "Old value";
$messages['pager_all'] = "All";
$messages['passwordchanged'] = "Password changed";
$messages['passwordexpired'] = "Password is expired";
$messages['passwordinhistory'] = "Password in history";
$messages['passwordinvalid'] = "Password is incorrect";
$messages['passwordok'] = "Authentication succeeds!";
$messages['password'] = "Password";
$messages['passwordrefused'] = "Password was refused";
$messages['passwordrequired'] = "Please enter the password";
$messages['policycomplex'] = "Minimum number of different classes of characters:";
$messages['policydifflogin'] = "Your new password may not be the same as your login";
$messages['policydiffminchars'] = "Minimum number of new unique characters:";
$messages['policyentropy'] = "Password strength";
$messages['policyforbiddenchars'] = "Forbidden characters:";
$messages['policyforbiddenldapfields'] = "Your password may not contain values from the following LDAP fields:";
$messages['policyforbiddenwords'] = "Your password must not contain:";
$messages['policymaxlength'] = "Maximum length:";
$messages['policymindigit'] = "Minimum number of digits:";
$messages['policyminlength'] = "Minimum length:";
$messages['policyminlower'] = "Minimum number of lowercase characters:";
$messages['policyminspecial'] = "Minimum number of special characters:";
$messages['policyminupper'] = "Minimum number of uppercase characters:";
$messages['policynoreusecustompwdfield'] = "Your new password may not be the same as your login password";
$messages['policynoreuse'] = "Your new password may not be the same as your old password";
$messages['policypwned'] = "Your new password may not be published on any previous public password leak from any site";
$messages['policyspecialatends'] = "Your new password may not have its only special character at the beginning or end";
$messages['policy'] = "Your password must conform to the following constraints:";
$messages['print_all'] = "Print all results";
$messages['print_page'] = "Print this page";
$messages['pwned'] = "Your new password has already been published on leaks, you should consider changing it on any other service that it is in use";
$messages['refreshentry'] = "Refresh";
$messages['renameentry'] = "Rename";
$messages['renamefailed'] = "Rename has failed";
$messages['renameok'] = "Entry has been renamed";
$messages['resetpassword'] = "Reset password";
$messages['sambaaccountstatus'] = 'Account samba status';
$messages['sameascustompwd'] = "The new password is not unique across other password fields";
$messages['sameaslogin'] = "Your new password is identical to your login";
$messages['sameasold'] = "Your new password is identical to your old password";
$messages['searchrequired'] = "Please enter your search";
$messages['search'] = "Search";
$messages['sizelimit'] = "Size limit has been reached, some entries could not be displayed";
$messages['specialatends'] = "Your new password has its only special character at the beginning or end";
$messages['startdate'] = "Start date";
$messages['submit'] = "Submit";
$messages['title_search'] = "Search results:";
$messages['title'] = "Service Desk";
$messages['toobig'] = "Your password is too long";
$messages['tooltip_emailto'] = "Send an email";
$messages['tooltip_phoneto'] = "Dial this number";
$messages['tooshort'] = "Your password is too short";
$messages['true'] = "Yes";
$messages['unlockaccount'] = "Unlock account";
$messages['unlockdate'] = "Automatic unlock date:";
$messages['updateentry'] = "Update entry";
$messages['updatefailed'] = "Modification has failed";
$messages['updateok'] = "Entry has been modified";
$messages['updatevaliditydates'] = "Update validity dates";
$messages['validitydatesnotupdated'] = "Error when updating validity dates";
$messages['validitydatesupdated'] = "Validity dates updated";
$messages['welcome'] = "Welcome to LDAP Tool Box service desk";
$messages['willexpireaccounts'] = "Passwords soon expired";
$messages['willexpireaccountstitle'] = "Passwords that will expire within $willexpiredays days";

?>
